# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_kubernetes_nonnamespaced_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.certificates import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_certificates_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.admissionregistration import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_admissionregistration_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.networking import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_networking_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.node import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_node_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.rbac import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_rbac_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;kubernetes/kubernetes_kubernetes_nonnamespaced_bundle.proto\x12.sac_kubernetes.kubernetes_nonnamespaced_bundle\x1a\x13shared/shared.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a\x36kubernetes/kubernetes_io.k8s.api.certificates.v1.proto\x1a?kubernetes/kubernetes_io.k8s.api.admissionregistration.v1.proto\x1a\x34kubernetes/kubernetes_io.k8s.api.networking.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.node.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.rbac.v1.proto\"\x82\x07\n\x18Kubernetes_NonNamespaced\x12\x46\n\x10\x63omponent_status\x18\x01 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.ComponentStatus\x12\x39\n\tnamespace\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.Namespace\x12/\n\x04node\x18\x03 \x03(\x0b\x32!.oak9.tython.k8s.api.core.v1.Node\x12H\n\x11persistent_volume\x18\x04 \x03(\x0b\x32-.oak9.tython.k8s.api.core.v1.PersistentVolume\x12\x63\n\x1b\x63\x65rtificate_signing_request\x18\x05 \x03(\x0b\x32>.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequest\x12r\n\x1emutating_webhook_configuration\x18\x06 \x03(\x0b\x32J.oak9.tython.k8s.api.admissionregistration.v1.MutatingWebhookConfiguration\x12v\n validating_webhook_configuration\x18\x07 \x03(\x0b\x32L.oak9.tython.k8s.api.admissionregistration.v1.ValidatingWebhookConfiguration\x12\x46\n\ringress_class\x18\x08 \x03(\x0b\x32/.oak9.tython.k8s.api.networking.v1.IngressClass\x12@\n\rruntime_class\x18\t \x03(\x0b\x32).oak9.tython.k8s.api.node.v1.RuntimeClass\x12M\n\x14\x63luster_role_binding\x18\n \x03(\x0b\x32/.oak9.tython.k8s.api.rbac.v1.ClusterRoleBinding\x12>\n\x0c\x63luster_role\x18\x0b \x03(\x0b\x32(.oak9.tython.k8s.api.rbac.v1.ClusterRoleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_kubernetes_nonnamespaced_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KUBERNETES_NONNAMESPACED._serialized_start=452
  _KUBERNETES_NONNAMESPACED._serialized_end=1350
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_security.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_security.proto\x12 oak9.tython.gcp.compute_security\x1a\x13shared/shared.proto\"q\nFComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x17\n\x0frule_visibility\x18\x02 \x01(\t\"\xc0\x01\n.ComputeSecurityPolicyXAdaptiveProtectionConfig\x12\x8d\x01\n\x1blayer_7_ddos_defense_config\x18\x01 \x01(\x0b\x32h.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig\"V\n+ComputeSecurityPolicyXAdvancedOptionsConfig\x12\x14\n\x0cjson_parsing\x18\x01 \x01(\t\x12\x11\n\tlog_level\x18\x02 \x01(\t\"@\n\'ComputeSecurityPolicyXRuleXMatchXConfig\x12\x15\n\rsrc_ip_ranges\x18\x01 \x03(\t\";\n%ComputeSecurityPolicyXRuleXMatchXExpr\x12\x12\n\nexpression\x18\x01 \x01(\t\"\xec\x01\n ComputeSecurityPolicyXRuleXMatch\x12\x16\n\x0eversioned_expr\x18\x01 \x01(\t\x12Y\n\x06\x63onfig\x18\x02 \x01(\x0b\x32I.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXMatchXConfig\x12U\n\x04\x65xpr\x18\x03 \x01(\x0b\x32G.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXMatchXExpr\"_\n8ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x14\n\x0cinterval_sec\x18\x02 \x01(\x01\"a\nAComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"e\n>ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x14\n\x0cinterval_sec\x18\x02 \x01(\x01\"\xa5\x04\n+ComputeSecurityPolicyXRuleXRateLimitOptions\x12\x18\n\x10\x62\x61n_duration_sec\x18\x01 \x01(\x01\x12\x16\n\x0e\x63onform_action\x18\x02 \x01(\t\x12\x16\n\x0e\x65nforce_on_key\x18\x03 \x01(\t\x12\x1b\n\x13\x65nforce_on_key_name\x18\x04 \x01(\t\x12\x15\n\rexceed_action\x18\x05 \x01(\t\x12q\n\rban_threshold\x18\x06 \x01(\x0b\x32Z.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold\x12\x84\x01\n\x17\x65xceed_redirect_options\x18\x07 \x01(\x0b\x32\x63.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions\x12~\n\x14rate_limit_threshold\x18\x08 \x01(\x0b\x32`.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold\"J\n*ComputeSecurityPolicyXRuleXRedirectOptions\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x8a\x03\n\x1a\x43omputeSecurityPolicyXRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07preview\x18\x03 \x01(\x08\x12\x10\n\x08priority\x18\x04 \x01(\x01\x12Q\n\x05match\x18\x05 \x01(\x0b\x32\x42.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXMatch\x12i\n\x12rate_limit_options\x18\x06 \x01(\x0b\x32M.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRateLimitOptions\x12\x66\n\x10redirect_options\x18\x07 \x01(\x0b\x32L.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRuleXRedirectOptions\"P\n\x1e\x43omputeSecurityPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcc\x04\n\x15\x43omputeSecurityPolicy\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x11\n\tself_link\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\x12t\n\x1a\x61\x64\x61ptive_protection_config\x18\x08 \x01(\x0b\x32P.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXAdaptiveProtectionConfig\x12n\n\x17\x61\x64vanced_options_config\x18\t \x01(\x0b\x32M.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXAdvancedOptionsConfig\x12J\n\x04rule\x18\n \x03(\x0b\x32<.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXRule\x12R\n\x08timeouts\x18\x0b \x01(\x0b\x32@.oak9.tython.gcp.compute_security.ComputeSecurityPolicyXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_security_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESECURITYPOLICYXADAPTIVEPROTECTIONCONFIGXLAYER7DDOSDEFENSECONFIG._serialized_start=89
  _COMPUTESECURITYPOLICYXADAPTIVEPROTECTIONCONFIGXLAYER7DDOSDEFENSECONFIG._serialized_end=202
  _COMPUTESECURITYPOLICYXADAPTIVEPROTECTIONCONFIG._serialized_start=205
  _COMPUTESECURITYPOLICYXADAPTIVEPROTECTIONCONFIG._serialized_end=397
  _COMPUTESECURITYPOLICYXADVANCEDOPTIONSCONFIG._serialized_start=399
  _COMPUTESECURITYPOLICYXADVANCEDOPTIONSCONFIG._serialized_end=485
  _COMPUTESECURITYPOLICYXRULEXMATCHXCONFIG._serialized_start=487
  _COMPUTESECURITYPOLICYXRULEXMATCHXCONFIG._serialized_end=551
  _COMPUTESECURITYPOLICYXRULEXMATCHXEXPR._serialized_start=553
  _COMPUTESECURITYPOLICYXRULEXMATCHXEXPR._serialized_end=612
  _COMPUTESECURITYPOLICYXRULEXMATCH._serialized_start=615
  _COMPUTESECURITYPOLICYXRULEXMATCH._serialized_end=851
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXBANTHRESHOLD._serialized_start=853
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXBANTHRESHOLD._serialized_end=948
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXEXCEEDREDIRECTOPTIONS._serialized_start=950
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXEXCEEDREDIRECTOPTIONS._serialized_end=1047
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXRATELIMITTHRESHOLD._serialized_start=1049
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONSXRATELIMITTHRESHOLD._serialized_end=1150
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONS._serialized_start=1153
  _COMPUTESECURITYPOLICYXRULEXRATELIMITOPTIONS._serialized_end=1702
  _COMPUTESECURITYPOLICYXRULEXREDIRECTOPTIONS._serialized_start=1704
  _COMPUTESECURITYPOLICYXRULEXREDIRECTOPTIONS._serialized_end=1778
  _COMPUTESECURITYPOLICYXRULE._serialized_start=1781
  _COMPUTESECURITYPOLICYXRULE._serialized_end=2175
  _COMPUTESECURITYPOLICYXTIMEOUTS._serialized_start=2177
  _COMPUTESECURITYPOLICYXTIMEOUTS._serialized_end=2257
  _COMPUTESECURITYPOLICY._serialized_start=2260
  _COMPUTESECURITYPOLICY._serialized_end=2848
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_storage_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_storage_pb2 as gcp_dot_gcp__storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#gcp/gcp_google_storage_bundle.proto\x12%oak9.tython.gcp.google_storage_bundle\x1a\x13shared/shared.proto\x1a\x15gcp/gcp_storage.proto\"\xfb\x08\n\rGoogleStorage\x12>\n\x0estorage_bucket\x18\x01 \x01(\x0b\x32&.oak9.tython.gcp.storage.StorageBucket\x12Z\n\x1dstorage_bucket_access_control\x18\x02 \x03(\x0b\x32\x33.oak9.tython.gcp.storage.StorageBucketAccessControl\x12\x45\n\x12storage_bucket_acl\x18\x03 \x03(\x0b\x32).oak9.tython.gcp.storage.StorageBucketAcl\x12T\n\x1astorage_bucket_iam_binding\x18\x04 \x03(\x0b\x32\x30.oak9.tython.gcp.storage.StorageBucketIamBinding\x12R\n\x19storage_bucket_iam_member\x18\x05 \x03(\x0b\x32/.oak9.tython.gcp.storage.StorageBucketIamMember\x12R\n\x19storage_bucket_iam_policy\x18\x06 \x03(\x0b\x32/.oak9.tython.gcp.storage.StorageBucketIamPolicy\x12K\n\x15storage_bucket_object\x18\x07 \x03(\x0b\x32,.oak9.tython.gcp.storage.StorageBucketObject\x12i\n%storage_default_object_access_control\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.storage.StorageDefaultObjectAccessControl\x12T\n\x1astorage_default_object_acl\x18\t \x01(\x0b\x32\x30.oak9.tython.gcp.storage.StorageDefaultObjectAcl\x12\x41\n\x10storage_hmac_key\x18\n \x01(\x0b\x32\'.oak9.tython.gcp.storage.StorageHmacKey\x12J\n\x14storage_notification\x18\x0b \x01(\x0b\x32,.oak9.tython.gcp.storage.StorageNotification\x12Z\n\x1dstorage_object_access_control\x18\x0c \x03(\x0b\x32\x33.oak9.tython.gcp.storage.StorageObjectAccessControl\x12\x45\n\x12storage_object_acl\x18\r \x03(\x0b\x32).oak9.tython.gcp.storage.StorageObjectAcl\x12I\n\x14storage_transfer_job\x18\x0e \x01(\x0b\x32+.oak9.tython.gcp.storage.StorageTransferJobb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_storage_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLESTORAGE._serialized_start=123
  _GOOGLESTORAGE._serialized_end=1270
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CertificateManagerCertificateXManaged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_AUTHORIZATIONS_FIELD_NUMBER: builtins.int
    DOMAINS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def dns_authorizations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    state: builtins.str
    def __init__(
        self,
        *,
        dns_authorizations: collections.abc.Iterable[builtins.str] | None = ...,
        domains: collections.abc.Iterable[builtins.str] | None = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_authorizations", b"dns_authorizations", "domains", b"domains", "state", b"state"]) -> None: ...

global___CertificateManagerCertificateXManaged = CertificateManagerCertificateXManaged

@typing_extensions.final
class CertificateManagerCertificateXSelfManaged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_PEM_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_PEM_FIELD_NUMBER: builtins.int
    certificate_pem: builtins.str
    private_key_pem: builtins.str
    def __init__(
        self,
        *,
        certificate_pem: builtins.str = ...,
        private_key_pem: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_pem", b"certificate_pem", "private_key_pem", b"private_key_pem"]) -> None: ...

global___CertificateManagerCertificateXSelfManaged = CertificateManagerCertificateXSelfManaged

@typing_extensions.final
class CertificateManagerCertificateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CertificateManagerCertificateXTimeouts = CertificateManagerCertificateXTimeouts

@typing_extensions.final
class CertificateManagerCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    MANAGED_FIELD_NUMBER: builtins.int
    SELF_MANAGED_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    scope: builtins.str
    @property
    def managed(self) -> global___CertificateManagerCertificateXManaged: ...
    @property
    def self_managed(self) -> global___CertificateManagerCertificateXSelfManaged: ...
    @property
    def timeouts(self) -> global___CertificateManagerCertificateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        scope: builtins.str = ...,
        managed: global___CertificateManagerCertificateXManaged | None = ...,
        self_managed: global___CertificateManagerCertificateXSelfManaged | None = ...,
        timeouts: global___CertificateManagerCertificateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed", b"managed", "resource_info", b"resource_info", "self_managed", b"self_managed", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "labels", b"labels", "managed", b"managed", "name", b"name", "project", b"project", "resource_info", b"resource_info", "scope", b"scope", "self_managed", b"self_managed", "timeouts", b"timeouts"]) -> None: ...

global___CertificateManagerCertificate = CertificateManagerCertificate

@typing_extensions.final
class CertificateManagerCertificateMapXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CertificateManagerCertificateMapXTimeouts = CertificateManagerCertificateMapXTimeouts

@typing_extensions.final
class CertificateManagerCertificateMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GclbTargetsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GCLB_TARGETS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    @property
    def gclb_targets(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___CertificateManagerCertificateMapXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        gclb_targets: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___CertificateManagerCertificateMapXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "gclb_targets", b"gclb_targets", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___CertificateManagerCertificateMap = CertificateManagerCertificateMap

@typing_extensions.final
class CertificateManagerCertificateMapEntryXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CertificateManagerCertificateMapEntryXTimeouts = CertificateManagerCertificateMapEntryXTimeouts

@typing_extensions.final
class CertificateManagerCertificateMapEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CERTIFICATES_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MAP_FIELD_NUMBER: builtins.int
    MATCHER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    create_time: builtins.str
    description: builtins.str
    hostname: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    map: builtins.str
    matcher: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___CertificateManagerCertificateMapEntryXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificates: collections.abc.Iterable[builtins.str] | None = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        hostname: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        map: builtins.str = ...,
        matcher: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___CertificateManagerCertificateMapEntryXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificates", b"certificates", "create_time", b"create_time", "description", b"description", "hostname", b"hostname", "id", b"id", "labels", b"labels", "map", b"map", "matcher", b"matcher", "name", b"name", "project", b"project", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___CertificateManagerCertificateMapEntry = CertificateManagerCertificateMapEntry

@typing_extensions.final
class CertificateManagerDnsAuthorizationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CertificateManagerDnsAuthorizationXTimeouts = CertificateManagerDnsAuthorizationXTimeouts

@typing_extensions.final
class CertificateManagerDnsAuthorization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DnsResourceRecordEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DNS_RESOURCE_RECORD_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def dns_resource_record(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    domain: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___CertificateManagerDnsAuthorizationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        dns_resource_record: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        domain: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___CertificateManagerDnsAuthorizationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "dns_resource_record", b"dns_resource_record", "domain", b"domain", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___CertificateManagerDnsAuthorization = CertificateManagerDnsAuthorization



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_essential.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_essential.proto\x12\x19oak9.tython.gcp.essential\x1a\x13shared/shared.proto\"S\n!EssentialContactsContactXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9f\x02\n\x18\x45ssentialContactsContact\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x14\n\x0clanguage_tag\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12+\n#notification_category_subscriptions\x18\x05 \x03(\t\x12\x0e\n\x06parent\x18\x06 \x01(\t\x12N\n\x08timeouts\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.essential.EssentialContactsContactXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_essential_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ESSENTIALCONTACTSCONTACTXTIMEOUTS._serialized_start=75
  _ESSENTIALCONTACTSCONTACTXTIMEOUTS._serialized_end=158
  _ESSENTIALCONTACTSCONTACT._serialized_start=161
  _ESSENTIALCONTACTSCONTACT._serialized_end=448
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ScalingPlanTagFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___ScalingPlanTagFilter = ScalingPlanTagFilter

@typing_extensions.final
class ScalingPlanApplicationSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_FORMATION_STACK_ARN_FIELD_NUMBER: builtins.int
    TAG_FILTERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cloud_formation_stack_arn: builtins.str
    @property
    def tag_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPlanTagFilter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_formation_stack_arn: builtins.str = ...,
        tag_filters: collections.abc.Iterable[global___ScalingPlanTagFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_formation_stack_arn", b"cloud_formation_stack_arn", "resource_info", b"resource_info", "tag_filters", b"tag_filters"]) -> None: ...

global___ScalingPlanApplicationSource = ScalingPlanApplicationSource

@typing_extensions.final
class ScalingPlanPredefinedScalingMetricSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_LABEL_FIELD_NUMBER: builtins.int
    PREDEFINED_SCALING_METRIC_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_label: builtins.str
    predefined_scaling_metric_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_label: builtins.str = ...,
        predefined_scaling_metric_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["predefined_scaling_metric_type", b"predefined_scaling_metric_type", "resource_info", b"resource_info", "resource_label", b"resource_label"]) -> None: ...

global___ScalingPlanPredefinedScalingMetricSpecification = ScalingPlanPredefinedScalingMetricSpecification

@typing_extensions.final
class ScalingPlanMetricDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ScalingPlanMetricDimension = ScalingPlanMetricDimension

@typing_extensions.final
class ScalingPlanCustomizedScalingMetricSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    STATISTIC_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    metric_name: builtins.str
    statistic: builtins.str
    @property
    def dimensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPlanMetricDimension]: ...
    unit: builtins.str
    namespace: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        metric_name: builtins.str = ...,
        statistic: builtins.str = ...,
        dimensions: collections.abc.Iterable[global___ScalingPlanMetricDimension] | None = ...,
        unit: builtins.str = ...,
        namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dimensions", b"dimensions", "metric_name", b"metric_name", "namespace", b"namespace", "resource_info", b"resource_info", "statistic", b"statistic", "unit", b"unit"]) -> None: ...

global___ScalingPlanCustomizedScalingMetricSpecification = ScalingPlanCustomizedScalingMetricSpecification

@typing_extensions.final
class ScalingPlanTargetTrackingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SCALE_OUT_COOLDOWN_FIELD_NUMBER: builtins.int
    TARGET_VALUE_FIELD_NUMBER: builtins.int
    PREDEFINED_SCALING_METRIC_SPECIFICATION_FIELD_NUMBER: builtins.int
    DISABLE_SCALE_IN_FIELD_NUMBER: builtins.int
    SCALE_IN_COOLDOWN_FIELD_NUMBER: builtins.int
    ESTIMATED_INSTANCE_WARMUP_FIELD_NUMBER: builtins.int
    CUSTOMIZED_SCALING_METRIC_SPECIFICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    scale_out_cooldown: builtins.int
    target_value: builtins.float
    @property
    def predefined_scaling_metric_specification(self) -> global___ScalingPlanPredefinedScalingMetricSpecification: ...
    disable_scale_in: builtins.bool
    scale_in_cooldown: builtins.int
    estimated_instance_warmup: builtins.int
    @property
    def customized_scaling_metric_specification(self) -> global___ScalingPlanCustomizedScalingMetricSpecification: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        scale_out_cooldown: builtins.int = ...,
        target_value: builtins.float = ...,
        predefined_scaling_metric_specification: global___ScalingPlanPredefinedScalingMetricSpecification | None = ...,
        disable_scale_in: builtins.bool = ...,
        scale_in_cooldown: builtins.int = ...,
        estimated_instance_warmup: builtins.int = ...,
        customized_scaling_metric_specification: global___ScalingPlanCustomizedScalingMetricSpecification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["customized_scaling_metric_specification", b"customized_scaling_metric_specification", "predefined_scaling_metric_specification", b"predefined_scaling_metric_specification", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["customized_scaling_metric_specification", b"customized_scaling_metric_specification", "disable_scale_in", b"disable_scale_in", "estimated_instance_warmup", b"estimated_instance_warmup", "predefined_scaling_metric_specification", b"predefined_scaling_metric_specification", "resource_info", b"resource_info", "scale_in_cooldown", b"scale_in_cooldown", "scale_out_cooldown", b"scale_out_cooldown", "target_value", b"target_value"]) -> None: ...

global___ScalingPlanTargetTrackingConfiguration = ScalingPlanTargetTrackingConfiguration

@typing_extensions.final
class ScalingPlanCustomizedLoadMetricSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    STATISTIC_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    metric_name: builtins.str
    statistic: builtins.str
    @property
    def dimensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPlanMetricDimension]: ...
    unit: builtins.str
    namespace: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        metric_name: builtins.str = ...,
        statistic: builtins.str = ...,
        dimensions: collections.abc.Iterable[global___ScalingPlanMetricDimension] | None = ...,
        unit: builtins.str = ...,
        namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dimensions", b"dimensions", "metric_name", b"metric_name", "namespace", b"namespace", "resource_info", b"resource_info", "statistic", b"statistic", "unit", b"unit"]) -> None: ...

global___ScalingPlanCustomizedLoadMetricSpecification = ScalingPlanCustomizedLoadMetricSpecification

@typing_extensions.final
class ScalingPlanPredefinedLoadMetricSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PREDEFINED_LOAD_METRIC_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_LABEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    predefined_load_metric_type: builtins.str
    resource_label: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        predefined_load_metric_type: builtins.str = ...,
        resource_label: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["predefined_load_metric_type", b"predefined_load_metric_type", "resource_info", b"resource_info", "resource_label", b"resource_label"]) -> None: ...

global___ScalingPlanPredefinedLoadMetricSpecification = ScalingPlanPredefinedLoadMetricSpecification

@typing_extensions.final
class ScalingPlanScalingInstruction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DISABLE_DYNAMIC_SCALING_FIELD_NUMBER: builtins.int
    SERVICE_NAMESPACE_FIELD_NUMBER: builtins.int
    PREDICTIVE_SCALING_MAX_CAPACITY_BEHAVIOR_FIELD_NUMBER: builtins.int
    SCALABLE_DIMENSION_FIELD_NUMBER: builtins.int
    SCALING_POLICY_UPDATE_BEHAVIOR_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    TARGET_TRACKING_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    PREDICTIVE_SCALING_MAX_CAPACITY_BUFFER_FIELD_NUMBER: builtins.int
    CUSTOMIZED_LOAD_METRIC_SPECIFICATION_FIELD_NUMBER: builtins.int
    PREDEFINED_LOAD_METRIC_SPECIFICATION_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    SCHEDULED_ACTION_BUFFER_TIME_FIELD_NUMBER: builtins.int
    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    PREDICTIVE_SCALING_MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    disable_dynamic_scaling: builtins.bool
    service_namespace: builtins.str
    predictive_scaling_max_capacity_behavior: builtins.str
    scalable_dimension: builtins.str
    scaling_policy_update_behavior: builtins.str
    min_capacity: builtins.int
    @property
    def target_tracking_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPlanTargetTrackingConfiguration]: ...
    predictive_scaling_max_capacity_buffer: builtins.int
    @property
    def customized_load_metric_specification(self) -> global___ScalingPlanCustomizedLoadMetricSpecification: ...
    @property
    def predefined_load_metric_specification(self) -> global___ScalingPlanPredefinedLoadMetricSpecification: ...
    resource_id: builtins.str
    scheduled_action_buffer_time: builtins.int
    max_capacity: builtins.int
    predictive_scaling_mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        disable_dynamic_scaling: builtins.bool = ...,
        service_namespace: builtins.str = ...,
        predictive_scaling_max_capacity_behavior: builtins.str = ...,
        scalable_dimension: builtins.str = ...,
        scaling_policy_update_behavior: builtins.str = ...,
        min_capacity: builtins.int = ...,
        target_tracking_configurations: collections.abc.Iterable[global___ScalingPlanTargetTrackingConfiguration] | None = ...,
        predictive_scaling_max_capacity_buffer: builtins.int = ...,
        customized_load_metric_specification: global___ScalingPlanCustomizedLoadMetricSpecification | None = ...,
        predefined_load_metric_specification: global___ScalingPlanPredefinedLoadMetricSpecification | None = ...,
        resource_id: builtins.str = ...,
        scheduled_action_buffer_time: builtins.int = ...,
        max_capacity: builtins.int = ...,
        predictive_scaling_mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["customized_load_metric_specification", b"customized_load_metric_specification", "predefined_load_metric_specification", b"predefined_load_metric_specification", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["customized_load_metric_specification", b"customized_load_metric_specification", "disable_dynamic_scaling", b"disable_dynamic_scaling", "max_capacity", b"max_capacity", "min_capacity", b"min_capacity", "predefined_load_metric_specification", b"predefined_load_metric_specification", "predictive_scaling_max_capacity_behavior", b"predictive_scaling_max_capacity_behavior", "predictive_scaling_max_capacity_buffer", b"predictive_scaling_max_capacity_buffer", "predictive_scaling_mode", b"predictive_scaling_mode", "resource_id", b"resource_id", "resource_info", b"resource_info", "scalable_dimension", b"scalable_dimension", "scaling_policy_update_behavior", b"scaling_policy_update_behavior", "scheduled_action_buffer_time", b"scheduled_action_buffer_time", "service_namespace", b"service_namespace", "target_tracking_configurations", b"target_tracking_configurations"]) -> None: ...

global___ScalingPlanScalingInstruction = ScalingPlanScalingInstruction

@typing_extensions.final
class ScalingPlan(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_SOURCE_FIELD_NUMBER: builtins.int
    SCALING_INSTRUCTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def application_source(self) -> global___ScalingPlanApplicationSource: ...
    @property
    def scaling_instructions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPlanScalingInstruction]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_source: global___ScalingPlanApplicationSource | None = ...,
        scaling_instructions: collections.abc.Iterable[global___ScalingPlanScalingInstruction] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application_source", b"application_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_source", b"application_source", "resource_info", b"resource_info", "scaling_instructions", b"scaling_instructions"]) -> None: ...

global___ScalingPlan = ScalingPlan

@typing_extensions.final
class AutoScalingPlans(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALING_PLAN_FIELD_NUMBER: builtins.int
    @property
    def scaling_plan(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPlan]: ...
    def __init__(
        self,
        *,
        scaling_plan: collections.abc.Iterable[global___ScalingPlan] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scaling_plan", b"scaling_plan"]) -> None: ...

global___AutoScalingPlans = AutoScalingPlans



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DataplexLakeXMetastore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    service: builtins.str
    def __init__(
        self,
        *,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service", b"service"]) -> None: ...

global___DataplexLakeXMetastore = DataplexLakeXMetastore

@typing_extensions.final
class DataplexLakeXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataplexLakeXTimeouts = DataplexLakeXTimeouts

@typing_extensions.final
class DataplexLake(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AssetStatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetastoreStatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ASSET_STATUS_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    METASTORE_STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    METASTORE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def asset_status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    create_time: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    @property
    def metastore_status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    service_account: builtins.str
    state: builtins.str
    uid: builtins.str
    update_time: builtins.str
    @property
    def metastore(self) -> global___DataplexLakeXMetastore: ...
    @property
    def timeouts(self) -> global___DataplexLakeXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        asset_status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        metastore_status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        service_account: builtins.str = ...,
        state: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        metastore: global___DataplexLakeXMetastore | None = ...,
        timeouts: global___DataplexLakeXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metastore", b"metastore", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset_status", b"asset_status", "create_time", b"create_time", "description", b"description", "display_name", b"display_name", "id", b"id", "labels", b"labels", "location", b"location", "metastore", b"metastore", "metastore_status", b"metastore_status", "name", b"name", "project", b"project", "resource_info", b"resource_info", "service_account", b"service_account", "state", b"state", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___DataplexLake = DataplexLake

@typing_extensions.final
class DataplexZoneXDiscoverySpecXCsvOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIMITER_FIELD_NUMBER: builtins.int
    DISABLE_TYPE_INFERENCE_FIELD_NUMBER: builtins.int
    ENCODING_FIELD_NUMBER: builtins.int
    HEADER_ROWS_FIELD_NUMBER: builtins.int
    delimiter: builtins.str
    disable_type_inference: builtins.bool
    encoding: builtins.str
    header_rows: builtins.float
    def __init__(
        self,
        *,
        delimiter: builtins.str = ...,
        disable_type_inference: builtins.bool = ...,
        encoding: builtins.str = ...,
        header_rows: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delimiter", b"delimiter", "disable_type_inference", b"disable_type_inference", "encoding", b"encoding", "header_rows", b"header_rows"]) -> None: ...

global___DataplexZoneXDiscoverySpecXCsvOptions = DataplexZoneXDiscoverySpecXCsvOptions

@typing_extensions.final
class DataplexZoneXDiscoverySpecXJsonOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_TYPE_INFERENCE_FIELD_NUMBER: builtins.int
    ENCODING_FIELD_NUMBER: builtins.int
    disable_type_inference: builtins.bool
    encoding: builtins.str
    def __init__(
        self,
        *,
        disable_type_inference: builtins.bool = ...,
        encoding: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_type_inference", b"disable_type_inference", "encoding", b"encoding"]) -> None: ...

global___DataplexZoneXDiscoverySpecXJsonOptions = DataplexZoneXDiscoverySpecXJsonOptions

@typing_extensions.final
class DataplexZoneXDiscoverySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    EXCLUDE_PATTERNS_FIELD_NUMBER: builtins.int
    INCLUDE_PATTERNS_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    CSV_OPTIONS_FIELD_NUMBER: builtins.int
    JSON_OPTIONS_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def exclude_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def include_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    schedule: builtins.str
    @property
    def csv_options(self) -> global___DataplexZoneXDiscoverySpecXCsvOptions: ...
    @property
    def json_options(self) -> global___DataplexZoneXDiscoverySpecXJsonOptions: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        exclude_patterns: collections.abc.Iterable[builtins.str] | None = ...,
        include_patterns: collections.abc.Iterable[builtins.str] | None = ...,
        schedule: builtins.str = ...,
        csv_options: global___DataplexZoneXDiscoverySpecXCsvOptions | None = ...,
        json_options: global___DataplexZoneXDiscoverySpecXJsonOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["csv_options", b"csv_options", "json_options", b"json_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["csv_options", b"csv_options", "enabled", b"enabled", "exclude_patterns", b"exclude_patterns", "include_patterns", b"include_patterns", "json_options", b"json_options", "schedule", b"schedule"]) -> None: ...

global___DataplexZoneXDiscoverySpec = DataplexZoneXDiscoverySpec

@typing_extensions.final
class DataplexZoneXResourceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_TYPE_FIELD_NUMBER: builtins.int
    location_type: builtins.str
    def __init__(
        self,
        *,
        location_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["location_type", b"location_type"]) -> None: ...

global___DataplexZoneXResourceSpec = DataplexZoneXResourceSpec

@typing_extensions.final
class DataplexZoneXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataplexZoneXTimeouts = DataplexZoneXTimeouts

@typing_extensions.final
class DataplexZone(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AssetStatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ASSET_STATUS_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LAKE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    DISCOVERY_SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_SPEC_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def asset_status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    create_time: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    lake: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    type: builtins.str
    uid: builtins.str
    update_time: builtins.str
    @property
    def discovery_spec(self) -> global___DataplexZoneXDiscoverySpec: ...
    @property
    def resource_spec(self) -> global___DataplexZoneXResourceSpec: ...
    @property
    def timeouts(self) -> global___DataplexZoneXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        asset_status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        lake: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        type: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        discovery_spec: global___DataplexZoneXDiscoverySpec | None = ...,
        resource_spec: global___DataplexZoneXResourceSpec | None = ...,
        timeouts: global___DataplexZoneXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["discovery_spec", b"discovery_spec", "resource_info", b"resource_info", "resource_spec", b"resource_spec", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset_status", b"asset_status", "create_time", b"create_time", "description", b"description", "discovery_spec", b"discovery_spec", "display_name", b"display_name", "id", b"id", "labels", b"labels", "lake", b"lake", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "resource_spec", b"resource_spec", "state", b"state", "timeouts", b"timeouts", "type", b"type", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___DataplexZone = DataplexZone



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DHCPOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_SERVERS_FIELD_NUMBER: builtins.int
    NETBIOS_NAME_SERVERS_FIELD_NUMBER: builtins.int
    NETBIOS_NODE_TYPE_FIELD_NUMBER: builtins.int
    NTP_SERVERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    domain_name: builtins.str
    @property
    def domain_name_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def netbios_name_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    netbios_node_type: builtins.int
    @property
    def ntp_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        domain_name: builtins.str = ...,
        domain_name_servers: collections.abc.Iterable[builtins.str] | None = ...,
        netbios_name_servers: collections.abc.Iterable[builtins.str] | None = ...,
        netbios_node_type: builtins.int = ...,
        ntp_servers: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name", b"domain_name", "domain_name_servers", b"domain_name_servers", "netbios_name_servers", b"netbios_name_servers", "netbios_node_type", b"netbios_node_type", "ntp_servers", b"ntp_servers", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DHCPOptions = DHCPOptions

@typing_extensions.final
class EC2_DHCPOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DHCP_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def dhcp_options(self) -> global___DHCPOptions: ...
    def __init__(
        self,
        *,
        dhcp_options: global___DHCPOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dhcp_options", b"dhcp_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dhcp_options", b"dhcp_options"]) -> None: ...

global___EC2_DHCPOptions = EC2_DHCPOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.authorization.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7kubernetes/kubernetes_io.k8s.api.authorization.v1.proto\x12$oak9.tython.k8s.api.authorization.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xe1\x02\n\x18LocalSubjectAccessReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12K\n\x04spec\x18\x04 \x01(\x0b\x32=.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewSpec\x12O\n\x06status\x18\x05 \x01(\x0b\x32?.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n\x15NonResourceAttributes\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04verb\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"v\n\x0fNonResourceRule\x12\x1b\n\x13non_resource_u_r_ls\x18\x01 \x03(\t\x12\r\n\x05verbs\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc3\x01\n\x12ResourceAttributes\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x10\n\x08resource\x18\x04 \x01(\t\x12\x13\n\x0bsubresource\x18\x05 \x01(\t\x12\x0c\n\x04verb\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x01\n\x0cResourceRule\x12\x12\n\napi_groups\x18\x01 \x03(\t\x12\x16\n\x0eresource_names\x18\x02 \x03(\t\x12\x11\n\tresources\x18\x03 \x03(\t\x12\r\n\x05verbs\x18\x04 \x03(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe4\x02\n\x17SelfSubjectAccessReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x04 \x01(\x0b\x32\x41.oak9.tython.k8s.api.authorization.v1.SelfSubjectAccessReviewSpec\x12O\n\x06status\x18\x05 \x01(\x0b\x32?.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x02\n\x1bSelfSubjectAccessReviewSpec\x12\\\n\x17non_resource_attributes\x18\x01 \x01(\x0b\x32;.oak9.tython.k8s.api.authorization.v1.NonResourceAttributes\x12U\n\x13resource_attributes\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.api.authorization.v1.ResourceAttributes\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe1\x02\n\x16SelfSubjectRulesReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x04 \x01(\x0b\x32@.oak9.tython.k8s.api.authorization.v1.SelfSubjectRulesReviewSpec\x12N\n\x06status\x18\x05 \x01(\x0b\x32>.oak9.tython.k8s.api.authorization.v1.SubjectRulesReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"h\n\x1aSelfSubjectRulesReviewSpec\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdc\x02\n\x13SubjectAccessReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12K\n\x04spec\x18\x04 \x01(\x0b\x32=.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewSpec\x12O\n\x06status\x18\x05 \x01(\x0b\x32?.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x03\n\x17SubjectAccessReviewSpec\x12W\n\x05\x65xtra\x18\x01 \x03(\x0b\x32H.oak9.tython.k8s.api.authorization.v1.SubjectAccessReviewSpec.ExtraEntry\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12\\\n\x17non_resource_attributes\x18\x03 \x01(\x0b\x32;.oak9.tython.k8s.api.authorization.v1.NonResourceAttributes\x12U\n\x13resource_attributes\x18\x04 \x01(\x0b\x32\x38.oak9.tython.k8s.api.authorization.v1.ResourceAttributes\x12\x0b\n\x03uid\x18\x05 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9f\x01\n\x19SubjectAccessReviewStatus\x12\x0f\n\x07\x61llowed\x18\x01 \x01(\x08\x12\x0e\n\x06\x64\x65nied\x18\x02 \x01(\x08\x12\x18\n\x10\x65valuation_error\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa0\x02\n\x18SubjectRulesReviewStatus\x12\x18\n\x10\x65valuation_error\x18\x01 \x01(\t\x12\x12\n\nincomplete\x18\x02 \x01(\x08\x12Q\n\x12non_resource_rules\x18\x03 \x03(\x0b\x32\x35.oak9.tython.k8s.api.authorization.v1.NonResourceRule\x12J\n\x0eresource_rules\x18\x04 \x03(\x0b\x32\x32.oak9.tython.k8s.api.authorization.v1.ResourceRule\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.authorization.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUBJECTACCESSREVIEWSPEC_EXTRAENTRY._options = None
  _SUBJECTACCESSREVIEWSPEC_EXTRAENTRY._serialized_options = b'8\001'
  _LOCALSUBJECTACCESSREVIEW._serialized_start=185
  _LOCALSUBJECTACCESSREVIEW._serialized_end=538
  _NONRESOURCEATTRIBUTES._serialized_start=540
  _NONRESOURCEATTRIBUTES._serialized_end=648
  _NONRESOURCERULE._serialized_start=650
  _NONRESOURCERULE._serialized_end=768
  _RESOURCEATTRIBUTES._serialized_start=771
  _RESOURCEATTRIBUTES._serialized_end=966
  _RESOURCERULE._serialized_start=969
  _RESOURCERULE._serialized_end=1118
  _SELFSUBJECTACCESSREVIEW._serialized_start=1121
  _SELFSUBJECTACCESSREVIEW._serialized_end=1477
  _SELFSUBJECTACCESSREVIEWSPEC._serialized_start=1480
  _SELFSUBJECTACCESSREVIEWSPEC._serialized_end=1747
  _SELFSUBJECTRULESREVIEW._serialized_start=1750
  _SELFSUBJECTRULESREVIEW._serialized_end=2103
  _SELFSUBJECTRULESREVIEWSPEC._serialized_start=2105
  _SELFSUBJECTRULESREVIEWSPEC._serialized_end=2209
  _SUBJECTACCESSREVIEW._serialized_start=2212
  _SUBJECTACCESSREVIEW._serialized_end=2560
  _SUBJECTACCESSREVIEWSPEC._serialized_start=2563
  _SUBJECTACCESSREVIEWSPEC._serialized_end=3004
  _SUBJECTACCESSREVIEWSPEC_EXTRAENTRY._serialized_start=2960
  _SUBJECTACCESSREVIEWSPEC_EXTRAENTRY._serialized_end=3004
  _SUBJECTACCESSREVIEWSTATUS._serialized_start=3007
  _SUBJECTACCESSREVIEWSTATUS._serialized_end=3166
  _SUBJECTRULESREVIEWSTATUS._serialized_start=3169
  _SUBJECTRULESREVIEWSTATUS._serialized_end=3457
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_spanner_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleSpanner(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPANNER_DATABASE_FIELD_NUMBER: builtins.int
    SPANNER_DATABASE_IAM_BINDING_FIELD_NUMBER: builtins.int
    SPANNER_DATABASE_IAM_MEMBER_FIELD_NUMBER: builtins.int
    SPANNER_DATABASE_IAM_POLICY_FIELD_NUMBER: builtins.int
    SPANNER_INSTANCE_FIELD_NUMBER: builtins.int
    SPANNER_INSTANCE_IAM_BINDING_FIELD_NUMBER: builtins.int
    SPANNER_INSTANCE_IAM_MEMBER_FIELD_NUMBER: builtins.int
    SPANNER_INSTANCE_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def spanner_database(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_spanner_pb2.SpannerDatabase]: ...
    @property
    def spanner_database_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_spanner_pb2.SpannerDatabaseIamBinding]: ...
    @property
    def spanner_database_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_spanner_pb2.SpannerDatabaseIamMember]: ...
    @property
    def spanner_database_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_spanner_pb2.SpannerDatabaseIamPolicy]: ...
    @property
    def spanner_instance(self) -> gcp.gcp_spanner_pb2.SpannerInstance: ...
    @property
    def spanner_instance_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_spanner_pb2.SpannerInstanceIamBinding]: ...
    @property
    def spanner_instance_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_spanner_pb2.SpannerInstanceIamMember]: ...
    @property
    def spanner_instance_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_spanner_pb2.SpannerInstanceIamPolicy]: ...
    def __init__(
        self,
        *,
        spanner_database: collections.abc.Iterable[gcp.gcp_spanner_pb2.SpannerDatabase] | None = ...,
        spanner_database_iam_binding: collections.abc.Iterable[gcp.gcp_spanner_pb2.SpannerDatabaseIamBinding] | None = ...,
        spanner_database_iam_member: collections.abc.Iterable[gcp.gcp_spanner_pb2.SpannerDatabaseIamMember] | None = ...,
        spanner_database_iam_policy: collections.abc.Iterable[gcp.gcp_spanner_pb2.SpannerDatabaseIamPolicy] | None = ...,
        spanner_instance: gcp.gcp_spanner_pb2.SpannerInstance | None = ...,
        spanner_instance_iam_binding: collections.abc.Iterable[gcp.gcp_spanner_pb2.SpannerInstanceIamBinding] | None = ...,
        spanner_instance_iam_member: collections.abc.Iterable[gcp.gcp_spanner_pb2.SpannerInstanceIamMember] | None = ...,
        spanner_instance_iam_policy: collections.abc.Iterable[gcp.gcp_spanner_pb2.SpannerInstanceIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spanner_instance", b"spanner_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["spanner_database", b"spanner_database", "spanner_database_iam_binding", b"spanner_database_iam_binding", "spanner_database_iam_member", b"spanner_database_iam_member", "spanner_database_iam_policy", b"spanner_database_iam_policy", "spanner_instance", b"spanner_instance", "spanner_instance_iam_binding", b"spanner_instance_iam_binding", "spanner_instance_iam_member", b"spanner_instance_iam_member", "spanner_instance_iam_policy", b"spanner_instance_iam_policy"]) -> None: ...

global___GoogleSpanner = GoogleSpanner



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_redshift.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_redshift.proto\x12\x18oak9.tython.aws.redshift\x1a\x13shared/shared.proto\"\x7f\n\x18\x43lusterLoggingProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x62ucket_name\x18\x02 \x01(\t\x12\x15\n\rs3_key_prefix\x18\x03 \x01(\t\"\xf3\x07\n\x07\x43luster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x61llow_version_upgrade\x18\x02 \x01(\x08\x12+\n#automated_snapshot_retention_period\x18\x03 \x01(\x05\x12\x19\n\x11\x61vailability_zone\x18\x04 \x01(\t\x12\x1a\n\x12\x63luster_identifier\x18\x05 \x01(\t\x12$\n\x1c\x63luster_parameter_group_name\x18\x06 \x01(\t\x12\x1f\n\x17\x63luster_security_groups\x18\x07 \x03(\t\x12!\n\x19\x63luster_subnet_group_name\x18\x08 \x01(\t\x12\x14\n\x0c\x63luster_type\x18\t \x01(\t\x12\x17\n\x0f\x63luster_version\x18\n \x01(\t\x12\x0f\n\x07\x64\x62_name\x18\x0b \x01(\t\x12\x12\n\nelastic_ip\x18\x0c \x01(\t\x12\x11\n\tencrypted\x18\r \x01(\x08\x12)\n!hsm_client_certificate_identifier\x18\x0e \x01(\t\x12$\n\x1chsm_configuration_identifier\x18\x0f \x01(\t\x12\x11\n\tiam_roles\x18\x10 \x03(\t\x12\x12\n\nkms_key_id\x18\x11 \x01(\t\x12N\n\x12logging_properties\x18\x12 \x01(\x0b\x32\x32.oak9.tython.aws.redshift.ClusterLoggingProperties\x12\x1c\n\x14master_user_password\x18\x13 \x01(\t\x12\x17\n\x0fmaster_username\x18\x14 \x01(\t\x12\x11\n\tnode_type\x18\x15 \x01(\t\x12\x17\n\x0fnumber_of_nodes\x18\x16 \x01(\x05\x12\x15\n\rowner_account\x18\x17 \x01(\t\x12\x0c\n\x04port\x18\x18 \x01(\x05\x12$\n\x1cpreferred_maintenance_window\x18\x19 \x01(\t\x12\x1b\n\x13publicly_accessible\x18\x1a \x01(\x08\x12#\n\x1bsnapshot_cluster_identifier\x18\x1b \x01(\t\x12\x1b\n\x13snapshot_identifier\x18\x1c \x01(\t\x12\x39\n\x04tags\x18\x1d \x03(\x0b\x32+.oak9.tython.aws.redshift.Cluster.TagsEntry\x12\x1e\n\x16vpc_security_group_ids\x18\x1e \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x03\n\x08Redshift\x12\x32\n\x07\x63luster\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.redshift.Cluster\x12P\n\x17\x63luster_parameter_group\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.redshift.ClusterParameterGroup\x12N\n\x16\x63luster_security_group\x18\x03 \x03(\x0b\x32..oak9.tython.aws.redshift.ClusterSecurityGroup\x12]\n\x1e\x63luster_security_group_ingress\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.redshift.ClusterSecurityGroupIngress\x12J\n\x14\x63luster_subnet_group\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.redshift.ClusterSubnetGroup\"\x8a\x01\n\x1e\x43lusterParameterGroupParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eparameter_name\x18\x02 \x01(\t\x12\x17\n\x0fparameter_value\x18\x03 \x01(\t\"\xc9\x02\n\x15\x43lusterParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x16parameter_group_family\x18\x03 \x01(\t\x12L\n\nparameters\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.redshift.ClusterParameterGroupParameter\x12G\n\x04tags\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.redshift.ClusterParameterGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x01\n\x14\x43lusterSecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x46\n\x04tags\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.redshift.ClusterSecurityGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd4\x01\n\x1b\x43lusterSecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12#\n\x1b\x63luster_security_group_name\x18\x03 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x04 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x05 \x01(\t\"\xe9\x01\n\x12\x43lusterSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x44\n\x04tags\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.redshift.ClusterSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_redshift_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLUSTER_TAGSENTRY._options = None
  _CLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERPARAMETERGROUP_TAGSENTRY._options = None
  _CLUSTERPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERSECURITYGROUP_TAGSENTRY._options = None
  _CLUSTERSECURITYGROUP_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERSUBNETGROUP_TAGSENTRY._options = None
  _CLUSTERSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERLOGGINGPROPERTIES._serialized_start=73
  _CLUSTERLOGGINGPROPERTIES._serialized_end=200
  _CLUSTER._serialized_start=203
  _CLUSTER._serialized_end=1214
  _CLUSTER_TAGSENTRY._serialized_start=1171
  _CLUSTER_TAGSENTRY._serialized_end=1214
  _REDSHIFT._serialized_start=1217
  _REDSHIFT._serialized_end=1612
  _CLUSTERPARAMETERGROUPPARAMETER._serialized_start=1615
  _CLUSTERPARAMETERGROUPPARAMETER._serialized_end=1753
  _CLUSTERPARAMETERGROUP._serialized_start=1756
  _CLUSTERPARAMETERGROUP._serialized_end=2085
  _CLUSTERPARAMETERGROUP_TAGSENTRY._serialized_start=1171
  _CLUSTERPARAMETERGROUP_TAGSENTRY._serialized_end=1214
  _CLUSTERSECURITYGROUP._serialized_start=2088
  _CLUSTERSECURITYGROUP._serialized_end=2305
  _CLUSTERSECURITYGROUP_TAGSENTRY._serialized_start=1171
  _CLUSTERSECURITYGROUP_TAGSENTRY._serialized_end=1214
  _CLUSTERSECURITYGROUPINGRESS._serialized_start=2308
  _CLUSTERSECURITYGROUPINGRESS._serialized_end=2520
  _CLUSTERSUBNETGROUP._serialized_start=2523
  _CLUSTERSUBNETGROUP._serialized_end=2756
  _CLUSTERSUBNETGROUP_TAGSENTRY._serialized_start=1171
  _CLUSTERSUBNETGROUP_TAGSENTRY._serialized_end=1214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_firewall.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_firewall.proto\x12 oak9.tython.gcp.compute_firewall\x1a\x13shared/shared.proto\"8\n\x15\x43omputeFirewallXAllow\x12\r\n\x05ports\x18\x01 \x03(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\"7\n\x14\x43omputeFirewallXDeny\x12\r\n\x05ports\x18\x01 \x03(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\"-\n\x19\x43omputeFirewallXLogConfig\x12\x10\n\x08metadata\x18\x01 \x01(\t\"J\n\x18\x43omputeFirewallXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe5\x05\n\x0f\x43omputeFirewall\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65stination_ranges\x18\x03 \x03(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x12\x16\n\x0e\x65nable_logging\x18\x06 \x01(\x08\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07network\x18\t \x01(\t\x12\x10\n\x08priority\x18\n \x01(\x01\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x11\n\tself_link\x18\x0c \x01(\t\x12\x15\n\rsource_ranges\x18\r \x03(\t\x12\x1f\n\x17source_service_accounts\x18\x0e \x03(\t\x12\x13\n\x0bsource_tags\x18\x0f \x03(\t\x12\x1f\n\x17target_service_accounts\x18\x10 \x03(\t\x12\x13\n\x0btarget_tags\x18\x11 \x03(\t\x12\x46\n\x05\x61llow\x18\x12 \x03(\x0b\x32\x37.oak9.tython.gcp.compute_firewall.ComputeFirewallXAllow\x12\x44\n\x04\x64\x65ny\x18\x13 \x03(\x0b\x32\x36.oak9.tython.gcp.compute_firewall.ComputeFirewallXDeny\x12O\n\nlog_config\x18\x14 \x01(\x0b\x32;.oak9.tython.gcp.compute_firewall.ComputeFirewallXLogConfig\x12L\n\x08timeouts\x18\x15 \x01(\x0b\x32:.oak9.tython.gcp.compute_firewall.ComputeFirewallXTimeouts\x12\x37\n\rresource_info\x18\x16 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x1e\x43omputeFirewallPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8c\x03\n\x15\x43omputeFirewallPolicy\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x03 \x01(\t\x12\x1a\n\x12\x66irewall_policy_id\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06parent\x18\x07 \x01(\t\x12\x18\n\x10rule_tuple_count\x18\x08 \x01(\x01\x12\x11\n\tself_link\x18\t \x01(\t\x12\x19\n\x11self_link_with_id\x18\n \x01(\t\x12\x12\n\nshort_name\x18\x0b \x01(\t\x12R\n\x08timeouts\x18\x0c \x01(\x0b\x32@.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"K\n)ComputeFirewallPolicyAssociationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x9c\x02\n ComputeFirewallPolicyAssociation\x12\x19\n\x11\x61ttachment_target\x18\x01 \x01(\t\x12\x17\n\x0f\x66irewall_policy\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x12\n\nshort_name\x18\x05 \x01(\t\x12]\n\x08timeouts\x18\x06 \x01(\x0b\x32K.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyAssociationXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"S\n-ComputeFirewallPolicyRuleXMatchXLayer4Configs\x12\x13\n\x0bip_protocol\x18\x01 \x01(\t\x12\r\n\x05ports\x18\x02 \x03(\t\"\xb9\x01\n\x1f\x43omputeFirewallPolicyRuleXMatch\x12\x16\n\x0e\x64\x65st_ip_ranges\x18\x01 \x03(\t\x12\x15\n\rsrc_ip_ranges\x18\x02 \x03(\t\x12g\n\x0elayer4_configs\x18\x03 \x03(\x0b\x32O.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyRuleXMatchXLayer4Configs\"T\n\"ComputeFirewallPolicyRuleXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfa\x03\n\x19\x43omputeFirewallPolicyRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x10\n\x08\x64isabled\x18\x04 \x01(\x08\x12\x16\n\x0e\x65nable_logging\x18\x05 \x01(\x08\x12\x17\n\x0f\x66irewall_policy\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04kind\x18\x08 \x01(\t\x12\x10\n\x08priority\x18\t \x01(\x01\x12\x18\n\x10rule_tuple_count\x18\n \x01(\x01\x12\x18\n\x10target_resources\x18\x0b \x03(\t\x12\x1f\n\x17target_service_accounts\x18\x0c \x03(\t\x12P\n\x05match\x18\r \x01(\x0b\x32\x41.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyRuleXMatch\x12V\n\x08timeouts\x18\x0e \x01(\x0b\x32\x44.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyRuleXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_firewall_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEFIREWALLXALLOW._serialized_start=89
  _COMPUTEFIREWALLXALLOW._serialized_end=145
  _COMPUTEFIREWALLXDENY._serialized_start=147
  _COMPUTEFIREWALLXDENY._serialized_end=202
  _COMPUTEFIREWALLXLOGCONFIG._serialized_start=204
  _COMPUTEFIREWALLXLOGCONFIG._serialized_end=249
  _COMPUTEFIREWALLXTIMEOUTS._serialized_start=251
  _COMPUTEFIREWALLXTIMEOUTS._serialized_end=325
  _COMPUTEFIREWALL._serialized_start=328
  _COMPUTEFIREWALL._serialized_end=1069
  _COMPUTEFIREWALLPOLICYXTIMEOUTS._serialized_start=1071
  _COMPUTEFIREWALLPOLICYXTIMEOUTS._serialized_end=1151
  _COMPUTEFIREWALLPOLICY._serialized_start=1154
  _COMPUTEFIREWALLPOLICY._serialized_end=1550
  _COMPUTEFIREWALLPOLICYASSOCIATIONXTIMEOUTS._serialized_start=1552
  _COMPUTEFIREWALLPOLICYASSOCIATIONXTIMEOUTS._serialized_end=1627
  _COMPUTEFIREWALLPOLICYASSOCIATION._serialized_start=1630
  _COMPUTEFIREWALLPOLICYASSOCIATION._serialized_end=1914
  _COMPUTEFIREWALLPOLICYRULEXMATCHXLAYER4CONFIGS._serialized_start=1916
  _COMPUTEFIREWALLPOLICYRULEXMATCHXLAYER4CONFIGS._serialized_end=1999
  _COMPUTEFIREWALLPOLICYRULEXMATCH._serialized_start=2002
  _COMPUTEFIREWALLPOLICYRULEXMATCH._serialized_end=2187
  _COMPUTEFIREWALLPOLICYRULEXTIMEOUTS._serialized_start=2189
  _COMPUTEFIREWALLPOLICYRULEXTIMEOUTS._serialized_end=2273
  _COMPUTEFIREWALLPOLICYRULE._serialized_start=2276
  _COMPUTEFIREWALLPOLICYRULE._serialized_end=2782
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    hours: builtins.float
    minutes: builtins.float
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        hours: builtins.float = ...,
        minutes: builtins.float = ...,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hours", b"hours", "minutes", b"minutes", "nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime = MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime

@typing_extensions.final
class MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    day: builtins.str
    duration: builtins.str
    @property
    def start_time(self) -> global___MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime: ...
    def __init__(
        self,
        *,
        day: builtins.str = ...,
        duration: builtins.str = ...,
        start_time: global___MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "duration", b"duration", "start_time", b"start_time"]) -> None: ...

global___MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindow = MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindow

@typing_extensions.final
class MemcacheInstanceXMaintenancePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    WEEKLY_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    update_time: builtins.str
    @property
    def weekly_maintenance_window(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindow]: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        update_time: builtins.str = ...,
        weekly_maintenance_window: collections.abc.Iterable[global___MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindow] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "update_time", b"update_time", "weekly_maintenance_window", b"weekly_maintenance_window"]) -> None: ...

global___MemcacheInstanceXMaintenancePolicy = MemcacheInstanceXMaintenancePolicy

@typing_extensions.final
class MemcacheInstanceXMemcacheParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "params", b"params"]) -> None: ...

global___MemcacheInstanceXMemcacheParameters = MemcacheInstanceXMemcacheParameters

@typing_extensions.final
class MemcacheInstanceXNodeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_COUNT_FIELD_NUMBER: builtins.int
    MEMORY_SIZE_MB_FIELD_NUMBER: builtins.int
    cpu_count: builtins.float
    memory_size_mb: builtins.float
    def __init__(
        self,
        *,
        cpu_count: builtins.float = ...,
        memory_size_mb: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_count", b"cpu_count", "memory_size_mb", b"memory_size_mb"]) -> None: ...

global___MemcacheInstanceXNodeConfig = MemcacheInstanceXNodeConfig

@typing_extensions.final
class MemcacheInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___MemcacheInstanceXTimeouts = MemcacheInstanceXTimeouts

@typing_extensions.final
class MemcacheInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MaintenanceScheduleEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MemcacheNodesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTHORIZED_NETWORK_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DISCOVERY_ENDPOINT_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MAINTENANCE_SCHEDULE_FIELD_NUMBER: builtins.int
    MEMCACHE_FULL_VERSION_FIELD_NUMBER: builtins.int
    MEMCACHE_NODES_FIELD_NUMBER: builtins.int
    MEMCACHE_VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NODE_COUNT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    MEMCACHE_PARAMETERS_FIELD_NUMBER: builtins.int
    NODE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    authorized_network: builtins.str
    create_time: builtins.str
    discovery_endpoint: builtins.str
    display_name: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def maintenance_schedule(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    memcache_full_version: builtins.str
    @property
    def memcache_nodes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    memcache_version: builtins.str
    name: builtins.str
    node_count: builtins.float
    project: builtins.str
    region: builtins.str
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def maintenance_policy(self) -> global___MemcacheInstanceXMaintenancePolicy: ...
    @property
    def memcache_parameters(self) -> global___MemcacheInstanceXMemcacheParameters: ...
    @property
    def node_config(self) -> global___MemcacheInstanceXNodeConfig: ...
    @property
    def timeouts(self) -> global___MemcacheInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        authorized_network: builtins.str = ...,
        create_time: builtins.str = ...,
        discovery_endpoint: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        maintenance_schedule: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        memcache_full_version: builtins.str = ...,
        memcache_nodes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        memcache_version: builtins.str = ...,
        name: builtins.str = ...,
        node_count: builtins.float = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        maintenance_policy: global___MemcacheInstanceXMaintenancePolicy | None = ...,
        memcache_parameters: global___MemcacheInstanceXMemcacheParameters | None = ...,
        node_config: global___MemcacheInstanceXNodeConfig | None = ...,
        timeouts: global___MemcacheInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["maintenance_policy", b"maintenance_policy", "memcache_parameters", b"memcache_parameters", "node_config", b"node_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorized_network", b"authorized_network", "create_time", b"create_time", "discovery_endpoint", b"discovery_endpoint", "display_name", b"display_name", "id", b"id", "labels", b"labels", "maintenance_policy", b"maintenance_policy", "maintenance_schedule", b"maintenance_schedule", "memcache_full_version", b"memcache_full_version", "memcache_nodes", b"memcache_nodes", "memcache_parameters", b"memcache_parameters", "memcache_version", b"memcache_version", "name", b"name", "node_config", b"node_config", "node_count", b"node_count", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts", "zones", b"zones"]) -> None: ...

global___MemcacheInstance = MemcacheInstance



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeHttpHealthCheckXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeHttpHealthCheckXTimeouts = ComputeHttpHealthCheckXTimeouts

@typing_extensions.final
class ComputeHttpHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECK_INTERVAL_SEC_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    check_interval_sec: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    healthy_threshold: builtins.float
    host: builtins.str
    id: builtins.str
    name: builtins.str
    port: builtins.float
    project: builtins.str
    request_path: builtins.str
    self_link: builtins.str
    timeout_sec: builtins.float
    unhealthy_threshold: builtins.float
    @property
    def timeouts(self) -> global___ComputeHttpHealthCheckXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        check_interval_sec: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        healthy_threshold: builtins.float = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        request_path: builtins.str = ...,
        self_link: builtins.str = ...,
        timeout_sec: builtins.float = ...,
        unhealthy_threshold: builtins.float = ...,
        timeouts: global___ComputeHttpHealthCheckXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_interval_sec", b"check_interval_sec", "creation_timestamp", b"creation_timestamp", "description", b"description", "healthy_threshold", b"healthy_threshold", "host", b"host", "id", b"id", "name", b"name", "port", b"port", "project", b"project", "request_path", b"request_path", "resource_info", b"resource_info", "self_link", b"self_link", "timeout_sec", b"timeout_sec", "timeouts", b"timeouts", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...

global___ComputeHttpHealthCheck = ComputeHttpHealthCheck
